@@ -29,7 +29,7 @@ use Readonly;
 
 use base qw(Exporter);
 
-our $VERSION     = '0.091.3';
+our $VERSION     = '0.091.4';
 
 our @EXPORT      = qw(latex_encode);
 our @EXPORT_OK   = qw(add_latex_encodings remove_latex_encodings reset_latex_encodings);
@@ -852,7 +852,7 @@ reset_latex_encodings(1);
 
 sub _compile_encoding_regexp {
     $encoded_char_re = join q{}, sort keys %latex_encoding;
-    $encoded_char_re =~ s{ ([#\[\]\\$]) }{\\$1}gmsx;
+    $encoded_char_re =~ s{ ([#\[\]\\\$]) }{\\$1}gmsx;
     $encoded_char_re = eval "qr{[$encoded_char_re]}x";
     return;
 }
@@ -881,7 +881,7 @@ LaTeX::Encode - encode characters for LaTeX formatting
 
 =head1 VERSION
 
-This manual page describes version 0.091.3 of the C<LaTeX::Encode> module.
+This manual page describes version 0.091.4 of the C<LaTeX::Encode> module.
 
 
 =head1 DESCRIPTION
